@@ -31,7 +31,6 @@
 #include <gtk/gtk.h>
 #include <gdk/gdkx.h>
 
-#include <glade/glade-xml.h>
 #include <gconf/gconf-client.h>
 
 #include "gsm-inhibit-dialog.h"
@@ -49,10 +48,10 @@
 
 #define IS_STRING_EMPTY(x) ((x)==NULL||(x)[0]=='\0')
 
-#define GLADE_XML_FILE "gsm-inhibit-dialog.glade"
+#define GTKBUILDER_FILE "gsm-inhibit-dialog.ui"
 
 #ifndef DEFAULT_ICON_SIZE
-#define DEFAULT_ICON_SIZE 64
+#define DEFAULT_ICON_SIZE 32
 #endif
 
 #ifndef DEFAULT_SNAPSHOT_SIZE
@@ -63,7 +62,7 @@
 
 struct GsmInhibitDialogPrivate
 {
-        GladeXML          *xml;
+        GtkBuilder        *xml;
         int                action;
         gboolean           is_done;
         GsmStore          *inhibitors;
@@ -521,18 +520,47 @@ add_inhibitor (GsmInhibitDialog *dialog,
         }
 
         if (desktop_filename != NULL) {
-                /* FIXME: maybe also append the autostart dirs ? */
-                search_dirs = gsm_util_get_app_dirs ();
+                search_dirs = gsm_util_get_desktop_dirs ();
 
-                error = NULL;
-                desktop_file = egg_desktop_file_new_from_dirs (desktop_filename,
-                                                               (const char **)search_dirs,
-                                                               &error);
+                if (g_path_is_absolute (desktop_filename)) {
+                        char *basename;
+
+                        error = NULL;
+                        desktop_file = egg_desktop_file_new (desktop_filename,
+                                                             &error);
+                        if (desktop_file == NULL) {
+                                if (error) {
+                                        g_warning ("Unable to load desktop file '%s': %s",
+                                                   desktop_filename, error->message);
+                                        g_error_free (error);
+                                } else {
+                                        g_warning ("Unable to load desktop file '%s'",
+                                                   desktop_filename);
+                                }
+
+                                basename = g_path_get_basename (desktop_filename);
+                                g_free (desktop_filename);
+                                desktop_filename = basename;
+                        }
+                }
+
+                if (desktop_file == NULL) {
+                        error = NULL;
+                        desktop_file = egg_desktop_file_new_from_dirs (desktop_filename,
+                                                                       (const char **)search_dirs,
+                                                                       &error);
+                }
 
                 /* look for a file with a vendor prefix */
                 if (desktop_file == NULL) {
-                        g_warning ("Unable to find desktop file '%s': %s", desktop_filename, error->message);
-                        g_error_free (error);
+                        if (error) {
+                                g_warning ("Unable to find desktop file '%s': %s",
+                                           desktop_filename, error->message);
+                                g_error_free (error);
+                        } else {
+                                g_warning ("Unable to find desktop file '%s'",
+                                           desktop_filename);
+                        }
                         g_free (desktop_filename);
                         desktop_filename = g_strdup_printf ("gnome-%s.desktop", app_id);
                         error = NULL;
@@ -543,8 +571,14 @@ add_inhibitor (GsmInhibitDialog *dialog,
                 g_strfreev (search_dirs);
 
                 if (desktop_file == NULL) {
-                        g_warning ("Unable to find desktop file '%s': %s", desktop_filename, error->message);
-                        g_error_free (error);
+                        if (error) {
+                                g_warning ("Unable to find desktop file '%s': %s",
+                                           desktop_filename, error->message);
+                                g_error_free (error);
+                        } else {
+                                g_warning ("Unable to find desktop file '%s'",
+                                           desktop_filename);
+                        }
                 } else {
                         name = egg_desktop_file_get_name (desktop_file);
                         icon_name = egg_desktop_file_get_icon (desktop_file);
@@ -632,12 +666,13 @@ update_dialog_text (GsmInhibitDialog *dialog)
                 header_text = _("A program is still running:");
                 description_text = _("Waiting for program to finish.  Interrupting program may cause you to lose work.");
         } else {
-                g_debug ("Found multiple entries in model");
+                g_debug ("Found multiple entries (or none) in model");
                 header_text = _("Some programs are still running:");
                 description_text = _("Waiting for programs to finish.  Interrupting these programs may cause you to lose work.");
         }
 
-        widget = glade_xml_get_widget (dialog->priv->xml, "header-label");
+        widget = GTK_WIDGET (gtk_builder_get_object (dialog->priv->xml,
+                                                     "header-label"));
         if (widget != NULL) {
                 char *markup;
                 markup = g_strdup_printf ("<b>%s</b>", header_text);
@@ -645,7 +680,8 @@ update_dialog_text (GsmInhibitDialog *dialog)
                 g_free (markup);
         }
 
-        widget = glade_xml_get_widget (dialog->priv->xml, "description-label");
+        widget = GTK_WIDGET (gtk_builder_get_object (dialog->priv->xml,
+                                                     "description-label"));
         if (widget != NULL) {
                 gtk_label_set_text (GTK_LABEL (widget), description_text);
         }
@@ -904,7 +940,8 @@ setup_dialog (GsmInhibitDialog *dialog)
                                                        G_TYPE_STRING,
                                                        G_TYPE_STRING);
 
-        treeview = glade_xml_get_widget (dialog->priv->xml, "inhibitors-treeview");
+        treeview = GTK_WIDGET (gtk_builder_get_object (dialog->priv->xml,
+                                                       "inhibitors-treeview"));
         gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (treeview), FALSE);
         gtk_tree_view_set_model (GTK_TREE_VIEW (treeview),
                                  GTK_TREE_MODEL (dialog->priv->list_store));
@@ -1051,22 +1088,36 @@ gsm_inhibit_dialog_class_init (GsmInhibitDialogClass *klass)
 static void
 gsm_inhibit_dialog_init (GsmInhibitDialog *dialog)
 {
+        GtkWidget *content_area;
         GtkWidget *widget;
+        GError    *error;
 
         dialog->priv = GSM_INHIBIT_DIALOG_GET_PRIVATE (dialog);
 
-        dialog->priv->xml = glade_xml_new (GLADEDIR "/" GLADE_XML_FILE,
-                                           "main-box",
-                                           PACKAGE);
-        g_assert (dialog->priv->xml != NULL);
+        dialog->priv->xml = gtk_builder_new ();
+        gtk_builder_set_translation_domain (dialog->priv->xml, GETTEXT_PACKAGE);
 
-        widget = glade_xml_get_widget (dialog->priv->xml, "main-box");
-        gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), widget);
+        error = NULL;
+        if (!gtk_builder_add_from_file (dialog->priv->xml,
+                                        GTKBUILDER_DIR "/" GTKBUILDER_FILE,
+                                        &error)) {
+                if (error) {
+                        g_warning ("Could not load inhibitor UI file: %s",
+                                   error->message);
+                        g_error_free (error);
+                } else {
+                        g_warning ("Could not load inhibitor UI file.");
+                }
+        }
 
-        gtk_container_set_border_width (GTK_CONTAINER (dialog), 12);
-        gtk_container_set_border_width (GTK_CONTAINER (widget), 12);
+        content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+        widget = GTK_WIDGET (gtk_builder_get_object (dialog->priv->xml,
+                                                     "main-box"));
+        gtk_container_add (GTK_CONTAINER (content_area), widget);
+
+        gtk_container_set_border_width (GTK_CONTAINER (dialog), 6);
         gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
-        gtk_window_set_icon_name (GTK_WINDOW (dialog), "gnome-logout");
+        gtk_window_set_icon_name (GTK_WINDOW (dialog), "system-log-out");
         gtk_window_set_title (GTK_WINDOW (dialog), "");
         g_object_set (dialog,
                       "allow-shrink", FALSE,
